marktools.get_stem_tremolo_attached_to_component
================================================

.. autofunction:: abjad.tools.marktools.get_stem_tremolo_attached_to_component.get_stem_tremolo_attached_to_component
